#region Using directives

using System;
using System.Data;
using System.Text;
using System.Drawing;
using System.Windows.Forms;
using System.ComponentModel;
using System.Collections.Generic;
using System.Runtime.Serialization;

using Perception.Sheets;
using Perception;

#endregion

namespace $safeprojectname$
{
     [SheetInfoRetriever(typeof(SheetControlInfoRetriever))]
     [SheetInformationProvider(typeof(SheetControlInfoProvider))]
     public partial class SheetControl : UserControl, ISheet
     {
          #region Members

          #region -> ISheet

          private string m_strUserName = Properties.Resources.IDS_USERNAME;

          private IProgram m_iProgram = null;
          private UIState m_UIState = UIState.Invisible;
          private InitializeState m_InitializeState = InitializeState.Unknown;
          private bool m_bDisposed = false;

          #endregion

          #endregion

          #region Constructor

          public SheetControl()
          {
               InitializeComponent();
          }

          #endregion

          #region ISheet Members

          #region -> Events

          /// <summary>
          /// Occurs when the user name of the sheet is changed.
          /// </summary>
          /// <remarks>
          /// Note that you should fire this event yourself when creating custom sheets.
          /// </remarks>
          public event EventHandler UserNameChanged;

#pragma warning disable 067
          /// <summary>
          /// Occurs when one or more toolbar items are updated.
          /// </summary>
          /// <remarks>
          /// Note that you should fire this event yourself when creating custom sheets.
          /// </remarks>
          public event EventHandler ToolItemsUpdated;

          /// <summary>
          /// Occurs when the sheet asks to rebuild the menu and Toolbar.
          /// </summary>
          /// <remarks>
          /// Note that you should fire this event yourself when creating custom sheets.
          /// </remarks>
          public event EventHandler RebuildDynamicMenuRequested;
#pragma warning restore 067

          #endregion

          #region -> Properties

          /// <summary>
          /// Gets/Sets the sheet username.
          /// </summary>
          public string UserName
          {
               get
               {
                    // Return the current UserName
                    return this.m_strUserName;
               }
               set
               {
                    // Compare the new UserName to the current UserName
                    if (String.Compare(this.m_strUserName, value) != 0)
                    {
                         // Set the new UserName
                         this.m_strUserName = value;

                         // Fire the UserNameChanged event
                         if (this.UserNameChanged != null)
                              this.UserNameChanged(this, new EventArgs());
                    }
               }
          }

          /// <summary>
          /// Gets the name of the dynamic dropdown menu entry for the sheet.
          /// </summary>
          public string MenuName
          {
               get
               {
                    if (String.IsNullOrEmpty(this.m_strUserName))
                    {
                         // Return a string from the resource table when no current User Name is available
                         return Properties.Resources.IDS_USERNAME;
                    }
                    else
                    {
                         // Return the current User Name
                         return this.m_strUserName;
                    }
               }
          }

          /// <summary>
          /// Gets the icon of the sheet.
          /// </summary>
          public Icon Icon
          {
               get
               {
                    return Properties.Resources.SheetIcon;
               }
          }

          /// <summary>
          /// Gets whether the delete may be actived. Application delete should delete the current active item on the sheet.
          /// </summary> 
          public bool DeleteActiveItemSupported
          {
               get
               {
                    return false;
               }
          }

          /// <summary>
          /// Gets/Sets the user-interface state of the sheet.
          /// </summary>
          public UIState UIState
          {
               get
               {
                    return this.m_UIState;
               }
               set
               {
                    this.m_UIState = value;
               }
          }

          /// <summary>
          /// Gets the initialization state of the sheet.
          /// </summary>
          public InitializeState InitializeState
          {
               get
               {
                    return this.m_InitializeState;
               }
          }

          #endregion

          #region -> Methods

          /// <summary>
          /// Update the items in the dynamic dropdown menu.
          /// </summary>
          public void UpdateMenuItems()
          {
          }

          /// <summary>
          /// Delete the actively selected item on the sheet.
          /// </summary>
          public void DeleteActiveItem()
          {
          }

          /// <summary>
          /// Perform steps to autoconfigure the sheet.
          /// </summary>
          public void AutoConfig()
          {
          }

          /// <summary>
          /// Initialize the sheet.
          /// </summary>
          /// <param name="iProgram">Interface to the program.</param>
          /// <returns>Returns <b>Succeeded</b> if the initialization is succesfull.</returns>
          public InitializeState Initialize(IProgram iProgram)
          {
               this.m_iProgram = iProgram;

               this.m_InitializeState = InitializeState.Succeeded;
               return this.m_InitializeState;
          }

          /// <summary>
          /// Perform steps that should be taken after a new settings file was loaded.
          /// </summary>
          public void PostLoad()
          {
          }

          /// <summary>
          /// Collect the dynamic dropdown menu.
          /// </summary>
          /// <returns>A toolstrip array containing the items in the dynamic dropdown menu.</returns>
          public ToolStripItem[] GetDynamicMenu()
          {
               return null;
          }

          /// <summary>
          /// Collect the dynamic toolbar menu.
          /// </summary>
          /// <returns>A toolstrip array containing the items in the dynamic toolbar menu.</returns>
          public ToolStripItem[] GetDynamicToolBar()
          {
               return null;
          }

          #endregion

          #endregion

          #region ISerializable Members

          /// <summary>
          /// Load data from saved stream (from VWB).
          /// </summary>
          /// <param name="info">Stream from which to load</param>
          public SheetControl(SerializationInfo info, StreamingContext context)
               : this()
          {
          }

          /// <summary>
          /// Save data into stream when saving VWB
          /// </summary>
          /// <param name="info">Stream in which to save</param>
          public void GetObjectData(SerializationInfo info, StreamingContext context)
          {
          }

          #endregion

          #region Disposing
          /// <summary>
          /// Procedure to do your cleanup, this function is called from within the Dispose() method.
          /// </summary>
          private void CleanUp()
          {
               if (m_bDisposed) return;

               try
               {
                    // Add your clean up code
               }
               catch
               {
               }
               m_bDisposed = true;
          }
          #endregion
     }
}